package	jp.co.sds_corp.hibiya.server;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

import jp.co.sds_corp.hibiya.action.IAction;
import jp.co.sds_corp.hibiya.threshold.IThreshold;
import jp.co.sds_corp.util.common.NoSuchCodeException;
import jp.co.sds_corp.util.daemon.IService;

public interface IChecker extends IService,
							ICheckerListener, ICheckerChanger, Serializable
{
	public enum Status {
		/** 状態：追加 */
		ADD,
		/** 状態：初期化 */
		INIT,
		/** 状態：正常 */
		OK,
		/** 状態：警告 */
		WARN,
		/** 状態：エラー */
		NG,
		/** 状態：削除 */
		DEL,
		/** 状態：不明 */
		UNKNOWN;

		public static Status parse( String code ) throws NoSuchCodeException {
			for ( Status stat : Status.values() ) {
				if ( stat.toString().equals( code )) {
					return stat;
				}
			}
			// return Status.UNKNOWN;
			throw( new NoSuchCodeException( "unknown status [" + code + "]" ));
		}
	};

	/**
	* 監視を実行します。
	*/
	public void check();

	/**
	* 状態を設定します。
	* @param	var		設定する状態
	*/
	public void setCheckerStatus( Status var );
	/**
	* 状態を取得します。
	* @return	状態
	*/
	public Status getCheckerStatus();
	/**
	* 状態を初期化します。
	*/
	public void clearCheckerStatus();

	/**
	* 監視対象の種別(type)を設定します。
	* @param	var		設定するデータ
	*/
	public void setType( String var );
	/**
	* 監視対象の種別(type)を取得します。
	* @return	typeの内容
	*/
	public String getType();
	/**
	* チェック結果を取得します。
	* @return	チェック結果
	*/
	public Map<Object,Object> getResults();
	/**
	* チェック結果を取得します。
	* @param	key		キー
	* @return	チェック結果
	*/
	public Object getResult( Object key );
	/**
	* チェック結果を設定します。
	* @param	key		キー
	* @param	value	チェック結果
	*/
	public void putResult( Object key, Object value );
	/**
	* レスポンスの帰ってきた時間を返します。
	*/
	public long getResponseTime();
	/**
	* 例外を設定します。
	* @param	var		例外
	*/
	public void setException( Throwable var );
	/**
	* 例外を取得します。
	* @return	例外
	*/
	public Throwable getException();

	/**
	* 監視間隔(interval)を設定します。
	* @param	var		設定するデータ
	*/
	public void setInterval( long var );
	/**
	* 監視間隔(interval)を取得します。
	* @return	intervalの内容
	*/
	public long getInterval();

	/**
	* このサービスに設定されているアクションを全てクリアします。
	*/
	public void clearAction();
	/**
	* このサービスにアクションを追加します。
	* @param	act		追加するアクション
	*/
	public void addAction( IAction act );
	/**
	* このサービスに設定されているアクションを返します。
	* @return	このサービスに設定されているアクション
	*/
	public List<IAction> getActionList();

	/**
	* このサービスにIThresholdを設定します。
	* @param	var		追加するIThreshold
	*/
	public void setThreshold( IThreshold var );
	/**
	* このサービスに設定されているIThresholdを返します。
	* @return	このサービスに設定されているIThreshold
	*/
	public IThreshold getThreshold();

	/**
	* 履歴保存フラグを設定します。
	* @param	var		設定するデータ
	*/
	public void setSaveHistory( boolean var );
	/**
	* 履歴保存フラグを取得します。
	* @return	履歴保存フラグ
	*/
	public boolean isSaveHistory();

	/**
	* デバッグフラグを設定します。
	* @param	var		設定するデータ
	*/
	public void setDebug( boolean var );
	/**
	* デバッグフラグを取得します。
	* @return	履歴保存フラグ
	*/
	public boolean isDebug();

	/**
	* 履歴を取得します。
	* @return	履歴
	*/
	public List<CheckerChangeEvent> listHistory();

	/**
	* hash値を取得します。
	* @return   hash値
	*/
	public int getHashCode();

}
