package	jp.co.sds_corp.hibiya.server;

import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.config.UnspecifiedPropertyException;

/**
IServiceの状況を監視します。
<BR>
XMLは以下の形式です。
<PRE>
&lt;Service name="Service1" class="jp.co.sds_corp.hibiya.server.ServiceChecker"&gt;
	&lt;Name&gt;192.168.0.1&lt;/Name&gt;
	&lt;Remote type="Socket"&gt;
		&lt;Host&gt;192.168.0.1&lt;/Host&gt;
		&lt;Port&gt;1090&lt;/Port&gt;
	&lt;/Remote&gt;
	&lt;Service&gt;DailyDaemon&lt;/Service&gt;
</PRE>

Action要素については、{@link jp.co.sds_corp.hibiya.action.IAction}
の説明を参照してください。
*/
public class ServiceChecker extends DaemonManagerChecker
{
	private static final long serialVersionUID = 1L;
	String	service;

	public ServiceChecker() {
		setType( "Service" );
	}

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );

		IConfiguration c = config.getChild( "Service" );
		if ( c == null ) {
			throw( new UnspecifiedPropertyException( "Service" ));
		}
		service = c.get();
	}

	/**
	* リモートコマンドを実行します。
	*/
	protected void command() throws Exception {
		Class<?>[] cls = { String.class };
		Object[] prm = { service };
		Object res = remote.execRemote( "getServiceStatus", cls, prm );
		putResult( "ServiceStatus", res );
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		config.addChild( "Service", service );
	}

	/**
	* このモニタの文字列表現を返します。
	* @return	このモニタの文字列表現
	*/
	public String toString() {
		String ret = super.toString();
		ret += "[" + service + "]";
		return ret;
	}

}
