package	jp.co.sds_corp.hibiya.action;

import jp.co.sds_corp.hibiya.layout.ILayout;
import jp.co.sds_corp.hibiya.server.CheckerChangeEvent;
import jp.co.sds_corp.util.audio.AudioPlay;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.log.CmnLogger;

/**
音を鳴らすアクションです。
XMLは以下の形式です。
<TABLE BORDER="1">
	<TR><TH>要素</TH><TH>必須</TH><TH>説明</TH><TH>備考</TH></TR>
	<TR><TD>File</TD><TD>※</TD><TD>音源ファイル</TD><TD>&nbsp;</TD></TR>
</TABLE>
<PRE>
&lt;Action class="jp.co.sds_corp.hibiya.action.SoundAction"&gt;
	&lt;File&gt;error.wav&lt;/File&gt;
&lt;/Action&gt;
</PRE>
*/
public class SoundAction extends AbstractAction
{
	private static final long serialVersionUID = 1L;
	static CmnLogger logger = CmnLogger.getInstance();
	String	file;
	int	time;

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );
		setFile( config.get( "File" ));
		setTime( config.getInteger( "Time", 1 ));
	}

	/**
	* アクションを実行します。
	*/
	public void action( CheckerChangeEvent ev ) {
		try {
			AudioPlay audio = new AudioPlay( getFile(), time );
			audio.start();
		} catch ( Exception ex ) {
			logger.error( this, "error", ex );
		}
	}

	/**
	* 設定内容の文字列表現を返します。
	*/
	public String paramString() {
		String ret = super.paramString();
		ret += file + "," + time;
		return ret;
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	親ノード
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		IConfiguration c;
		c = config.addChild( "File", getFile() );
		c = config.addChild( "Time", String.valueOf( getTime() ));
	}

	/**
	* syslogをフォーマットするILayout(layout)を設定します。
	* @param    var     設定するデータ
	*/
	public void setLayout( ILayout var ) {
		throw( new UnsupportedOperationException());
	}
	/**
	* syslogをフォーマットするILayout(layout)を取得します。
	* @return   layoutの内容
	*/
	public ILayout getLayout() {
		throw( new UnsupportedOperationException());
	}

	/**
	* 音源のファイル名(file)を設定します。
	* @param	var		設定するデータ
	*/
	public void setFile( String var ) {
		this.file = var ;
	}
	/**
	* 音源のファイル名(file)を取得します。
	* @return	fileの内容
	*/
	public String getFile() {
		return file;
	}

	/**
	* 回数(time)を設定します。
	* @param	var		設定するデータ
	*/
	public void setTime( int var ) {
		this.time = var ;
	}
	/**
	* 回数(time)を取得します。
	* @return	timeの内容
	*/
	public int getTime() {
		return time;
	}

}
